==> tepsonic-0.97.0-src.tar.gz: tepsonic-0.97.0/player/ts/cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs_CZ" sourcelanguage="en">
<context>
    <name>CollectionBuilder</name>
    <message>
        <source>Unkown artist</source>
        <translation>Neznámý umělec</translation>
    </message>
    <message>
        <source>Unknown album</source>
        <translation>Neznámé album</translation>
    </message>
</context>
<context>
    <name>CollectionPopulator</name>
    <message numerus="yes">
        <source>%n album(s)</source>
        <translation>
            <numerusform>%n album</numerusform>
            <numerusform>%n alba</numerusform>
            <numerusform>%n alb</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n track(s)</source>
        <translation>
            <numerusform>%n skladba</numerusform>
            <numerusform>%n skladby</numerusform>
            <numerusform>%n skladeb</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Collections</name>
    <message>
        <source>Form</source>
        <translation>Formulář</translation>
    </message>
    <message>
        <source>Collections</source>
        <translation>Kolekce</translation>
    </message>
    <message>
        <source>Enable collections</source>
        <translation>Zapnout kolekce</translation>
    </message>
    <message>
        <source>Update collections automatically after start</source>
        <translation>Automaticky aktualizovat kolekce po spuštění</translation>
    </message>
    <message>
        <source>Rebuild collections now</source>
        <translation>Aktualizovat kolekce nyní</translation>
    </message>
    <message>
        <source>Database engine</source>
        <translation>Databáze</translation>
    </message>
    <message>
        <source>SQLite</source>
        <translation>SQLite</translation>
    </message>
    <message>
        <source>MySQL</source>
        <translation>MySQL</translation>
    </message>
    <message>
        <source>MySQL settings</source>
        <translation>Konfigurace MySQL</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Server</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Uživ. jméno</translation>
    </message>
    <message>
        <source>Database</source>
        <translation>Databáze</translation>
    </message>
    <message>
        <source>Collections paths</source>
        <translation>Cesty kolekcí</translation>
    </message>
    <message>
        <source>Add...</source>
        <translation>Přidat...</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Odstranit</translation>
    </message>
    <message>
        <source>Remove all</source>
        <translation>Odtranit vše</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>TepSonic</source>
        <translation>TepSonic</translation>
    </message>
    <message>
        <source>Load file</source>
        <translation>Otevřít soubor</translation>
    </message>
    <message>
        <source>Load folder</source>
        <translation>Načíst adresář</translation>
    </message>
    <message>
        <source>Clear playlist</source>
        <translation>Vyprázdnit playlist</translation>
    </message>
    <message>
        <source>Player is stopped</source>
        <translation>Přehrávač je zastavený</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Zastaveno</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
    <message>
        <source>&amp;TepSonic</source>
        <translation>&amp;TepSonic</translation>
    </message>
    <message>
        <source>P&amp;laylist</source>
        <translation>&amp;Seznam skladeb</translation>
    </message>
    <message>
        <source>Visible columns</source>
        <translation>Viditelné sloupce</translation>
    </message>
    <message>
        <source>Pla&amp;yer</source>
        <translation>&amp;Přehrávač</translation>
    </message>
    <message>
        <source>&amp;Random</source>
        <translation>&amp;Náhodné přehrávání</translation>
    </message>
    <message>
        <source>&amp;Repeat</source>
        <translation>&amp;Opakování</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Nápověda</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>N&amp;astavení</translation>
    </message>
    <message>
        <source>&amp;Show/Hide</source>
        <translation>&amp;Zobrazit/Skrýt</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <source>&amp;Quit TepSonic</source>
        <translation>&amp;Ukončit TepSonic</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Add &amp;file</source>
        <translation>Přida&amp;t soubor</translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <source>&amp;Add folder</source>
        <translation>&amp;Načíst adresář</translation>
    </message>
    <message>
        <source>&amp;Clear playlist</source>
        <translation>&amp;Vyprázdnit playlist</translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <source>&amp;Save playlist</source>
        <translation>&amp;Uložit playlist</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>P&amp;revious track</source>
        <translation>&amp;Předchozí skladba</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Play/pause</source>
        <translation>&amp;Hrát/pauza</translation>
    </message>
    <message>
        <source>Space</source>
        <translation>Mezerník</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Zastavit</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>&amp;Next track</source>
        <translation>&amp;Další skladba</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>Random O&amp;N</source>
        <translation>&amp;Zapnout</translation>
    </message>
    <message>
        <source>Random O&amp;FF</source>
        <translation>&amp;Vypnout</translation>
    </message>
    <message>
        <source>Repeat &amp;OFF</source>
        <translation>&amp;Vypnout</translation>
    </message>
    <message>
        <source>Repeat &amp;track</source>
        <translation>&amp;Skladbu</translation>
    </message>
    <message>
        <source>Repeat &amp;playlist</source>
        <translation>&amp;Celý playlist</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <translation>&amp;Možnosti</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>About &amp;TepSonic</source>
        <translation>&amp;O TepSonicu</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>O &amp;Qt</translation>
    </message>
    <message>
        <source>&amp;Report a bug</source>
        <translation>&amp;Nahlásit chybu</translation>
    </message>
    <message>
        <source>&amp;Preferences</source>
        <translation>&amp;Volby</translation>
    </message>
    <message>
        <source>Track</source>
        <translation>Stopa</translation>
    </message>
    <message>
        <source>Interpret</source>
        <translation>Interpret</translation>
    </message>
    <message>
        <source>Track name</source>
        <translation>Skladba</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Genre</source>
        <translation>Žánr</translation>
    </message>
    <message>
        <source>Year</source>
        <translation>Rok</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Délka</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Název souboru</translation>
    </message>
    <message numerus="yes">
        <source>%n track(s)</source>
        <translation>
            <numerusform>%n skladba</numerusform>
            <numerusform>%n skladby</numerusform>
            <numerusform>%n skladeb</numerusform>
        </translation>
    </message>
    <message>
        <source>Expand all</source>
        <translation>Rozbalit vše</translation>
    </message>
    <message>
        <source>Collapse all</source>
        <translation>Zabalit vše</translation>
    </message>
    <message>
        <source>Delete file from disk</source>
        <translation>Odstranit z disku</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Verze %1</translation>
    </message>
    <message>
        <source>Developers</source>
        <translation>Vývojáři</translation>
    </message>
    <message>
        <source>Artwork</source>
        <translation>Artwork</translation>
    </message>
    <message>
        <source>About TepSonic</source>
        <translation>O TepSonicu</translation>
    </message>
    <message>
        <source>Select file</source>
        <translation>Vyberte soubor</translation>
    </message>
    <message>
        <source>Supported files (*.mp3 *.wav *.ogg *.flac *.m3u);;Playlists (*.m3u);;All files (*.*)</source>
        <translation>Podporované soubory (*.mp3 *.wav *.ogg *.flac *.m3u);;Playlisty (*.m3u);;Všechny soubor (*.*)</translation>
    </message>
    <message>
        <source>Add directory</source>
        <translation>Přidat adresář</translation>
    </message>
    <message>
        <source>Playing: </source>
        <translation>Přehrává se: </translation>
    </message>
    <message>
        <source>%1 [paused]</source>
        <translation>%1 [pozastaveno]</translation>
    </message>
    <message>
        <source>Save playlist to...</source>
        <translation>Uložit playlist jako...</translation>
    </message>
    <message>
        <source>M3U Playlist (*.m3u)</source>
        <translation>M3U Playlist (*.m3u)</translation>
    </message>
    <message>
        <source>Are you sure you want to remove all content of %1 from hard disk?</source>
        <translation>Opravdu chcete odstranit všechen obsah %1 z disku?</translation>
    </message>
    <message>
        <source>Are you sure you want to remove track %1 (%2) from hard disk?</source>
        <translation>Opravdu chcete odstranit skladbu %1 (%2) z disku?</translation>
    </message>
    <message>
        <source>Confirm removal</source>
        <translation>Potvrzení odstranění</translation>
    </message>
</context>
<context>
    <name>Player</name>
    <message>
        <source>Form</source>
        <translation>Formulář</translation>
    </message>
    <message>
        <source>Restore previous session</source>
        <translation>Obnovit přechozí sezení</translation>
    </message>
</context>
<context>
    <name>Plugins</name>
    <message>
        <source>Form</source>
        <translation>Formulář</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Hlavní</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Přehrávač</translation>
    </message>
    <message>
        <source>Collections</source>
        <translation>Kolekce</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>Pluginy</translation>
    </message>
</context>
<context>
    <name>PreferencesPages::Collections</name>
    <message>
        <source>Add directory</source>
        <translation>Přidat adresář</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation>
            <numerusform>%n týden</numerusform>
            <numerusform>%n týdny</numerusform>
            <numerusform>%n týdnů</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation>
            <numerusform>%n den</numerusform>
            <numerusform>%n dny</numerusform>
            <numerusform>%n dní</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>TaskManager</name>
    <message>
        <source>Rebuilding collections</source>
        <translation>Aktualizuji kolekce</translation>
    </message>
</context>
</TS>

==> tepsonic-0.98.2-src.tar.gz: tepsonic-0.98.2/player/ts/cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs_CZ" sourcelanguage="en">
<context>
    <name>AddBookmarkDlg</name>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation>Název:</translation>
    </message>
    <message>
        <source>Path:</source>
        <translation>Cesta:</translation>
    </message>
</context>
<context>
    <name>BookmarksManager</name>
    <message>
        <source>Remove bookmark</source>
        <translation>Odstranit záložku</translation>
    </message>
    <message>
        <source>Remove bookmark?</source>
        <translation>Odstranit záložku?</translation>
    </message>
    <message>
        <source>Do you really want to remove this bookmark?</source>
        <translation>Opravdu chcete odstranit tuto záložku?</translation>
    </message>
</context>
<context>
    <name>ChangeShortcutDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Press a keys that you want to set as a shortcut</source>
        <translation>Stiskněte klávesu, kterou chcete nastavit jako zkratku</translation>
    </message>
</context>
<context>
    <name>CollectionBuilder</name>
    <message>
        <source>Unkown artist</source>
        <translation>Neznámý umělec</translation>
    </message>
    <message>
        <source>Unknown album</source>
        <translation>Neznámé album</translation>
    </message>
</context>
<context>
    <name>CollectionPopulator</name>
    <message>
        <source>Various Artists</source>
        <translation>Různí umělci</translation>
    </message>
    <message numerus="yes">
        <source>%n album(s)</source>
        <translation>
            <numerusform>%n album</numerusform>
            <numerusform>%n alba</numerusform>
            <numerusform>%n alb</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n tracks(s)</source>
        <translation>
            <numerusform>%n stopa</numerusform>
            <numerusform>%n stopy</numerusform>
            <numerusform>%n stop</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n track(s)</source>
        <translation>
            <numerusform>%n stopa</numerusform>
            <numerusform>%n stopy</numerusform>
            <numerusform>%n stop</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>CollectionsPage</name>
    <message>
        <source>Form</source>
        <translation>Formulář</translation>
    </message>
    <message>
        <source>Collections</source>
        <translation>Kolekce</translation>
    </message>
    <message>
        <source>Enable collections</source>
        <translation>Povolit kolekce</translation>
    </message>
    <message>
        <source>Update collections automatically after start</source>
        <translation>Automaticky aktualizovat kolekce po startu</translation>
    </message>
    <message>
        <source>Rebuild collections now</source>
        <translation>Aktualizovat kolekce</translation>
    </message>
    <message>
        <source>Database engine</source>
        <translation>Databáze</translation>
    </message>
    <message>
        <source>SQLite</source>
        <translation>SQLite</translation>
    </message>
    <message>
        <source>MySQL</source>
        <translation>MySQL</translation>
    </message>
    <message>
        <source>MySQL settings</source>
        <translation>Nastavení MySQL</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Server</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Uživ. jméno</translation>
    </message>
    <message>
        <source>Database</source>
        <translation>Databáze</translation>
    </message>
    <message>
        <source>Collections paths</source>
        <translation>Zdroje kolekcí</translation>
    </message>
    <message>
        <source>Add...</source>
        <translation>Přidat...</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Odebrat</translation>
    </message>
    <message>
        <source>Remove all</source>
        <translation>Odebrat vše</translation>
    </message>
</context>
<context>
    <name>FileSystemBrowser</name>
    <message>
        <source>Add to bookmarks</source>
        <translation>Přidat do záložek</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>TepSonic</source>
        <translation>TepSonic</translation>
    </message>
    <message>
        <source>Clear playlist</source>
        <translation>Vymazat playlist</translation>
    </message>
    <message>
        <source>Player is stopped</source>
        <translation>Přehrávaní je zastavené</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Zastaveno</translation>
    </message>
    <message>
        <source>Collections</source>
        <translation>Kolekce</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
    <message>
        <source>Filesystem</source>
        <translation>Disk</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>O úroveň výše</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Vpřed</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Domů</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Záložky</translation>
    </message>
    <message>
        <source>/</source>
        <translation>/</translation>
    </message>
    <message>
        <source>&amp;TepSonic</source>
        <translation>&amp;TepSonic</translation>
    </message>
    <message>
        <source>P&amp;laylist</source>
        <translation>&amp;Seznam skladeb</translation>
    </message>
    <message>
        <source>Visible columns</source>
        <translation>Zobrazené sloupce</translation>
    </message>
    <message>
        <source>Pla&amp;yer</source>
        <translation>&amp;Přehrávač</translation>
    </message>
    <message>
        <source>&amp;Random</source>
        <translation>&amp;Náhodné přehrávání</translation>
    </message>
    <message>
        <source>&amp;Repeat</source>
        <translation>&amp;Opakování</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Nápověda</translation>
    </message>
    <message>
        <source>&amp;Show/Hide</source>
        <translation>&amp;Zobrazit/skrýt</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <source>Load folder</source>
        <translation>Načíst adresář</translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <source>&amp;Quit TepSonic</source>
        <translation>&amp;Ukončit TepSonic</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Add &amp;file</source>
        <translation>Přidat &amp;soubor</translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <source>&amp;Add folder</source>
        <translation>Přidat &amp;adresář</translation>
    </message>
    <message>
        <source>&amp;Clear playlist</source>
        <translation>&amp;Vymazat playlist</translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <source>&amp;Save playlist</source>
        <translation>&amp;Uložit playlist</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>P&amp;revious track</source>
        <translation>Pře&amp;dchozí skladba</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Play/pause</source>
        <translation>&amp;Play/pauza</translation>
    </message>
    <message>
        <source>Space</source>
        <translation>Mezerník</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Zastavit</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>&amp;Next track</source>
        <translation>&amp;Další skladba</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>Random O&amp;N</source>
        <translation>&amp;Zapnuto</translation>
    </message>
    <message>
        <source>Random O&amp;FF</source>
        <translation>&amp;Vypnuto</translation>
    </message>
    <message>
        <source>Repeat &amp;OFF</source>
        <translation>&amp;Vypnuto</translation>
    </message>
    <message>
        <source>Repeat &amp;track</source>
        <translation>Opakovat &amp;skladbu</translation>
    </message>
    <message>
        <source>Repeat &amp;playlist</source>
        <translation>Opakovat &amp;vše</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <translation>&amp;Nastavení</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>About &amp;TepSonic</source>
        <translation>O &amp;TepSonicu</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>O &amp;Qt</translation>
    </message>
    <message>
        <source>&amp;Report a bug</source>
        <translation>&amp;Nahlásit chybu</translation>
    </message>
    <message>
        <source>&amp;Preferences</source>
        <translation>&amp;Volby</translation>
    </message>
    <message>
        <source>Track</source>
        <translation>Číslo skladby</translation>
    </message>
    <message>
        <source>Interpret</source>
        <translation>Interpret</translation>
    </message>
    <message>
        <source>Track name</source>
        <translation>Skladba</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Genre</source>
        <translation>Žánr</translation>
    </message>
    <message>
        <source>Year</source>
        <translation>Rok</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Délka</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Soubor</translation>
    </message>
    <message>
        <source>Se&amp;ttings</source>
        <translation>&amp;Nastavení</translation>
    </message>
    <message>
        <source>Configure TepSonic</source>
        <translation>Nastavit TepSonic</translation>
    </message>
    <message>
        <source>Bitrate</source>
        <translation>Datový tok</translation>
    </message>
    <message>
        <source>&amp;Supported formats</source>
        <translation>&amp;Podporované formáty</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>O Qt</translation>
    </message>
    <message numerus="yes">
        <source>%n track(s)</source>
        <translation>
            <numerusform>%n skladba</numerusform>
            <numerusform>%n skladby</numerusform>
            <numerusform>%n skladeb</numerusform>
        </translation>
    </message>
    <message>
        <source>Expand all</source>
        <translation>Rozbalit vše</translation>
    </message>
    <message>
        <source>Collapse all</source>
        <translation>Sbalit vše</translation>
    </message>
    <message>
        <source>Delete file from disk</source>
        <translation>Odstranit soubor z disku</translation>
    </message>
    <message>
        <source>Stop after this track</source>
        <translation>Zastavit po této skladbě</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Verze %1</translation>
    </message>
    <message>
        <source>Developers</source>
        <translation>Vývojáři</translation>
    </message>
    <message>
        <source>Artwork</source>
        <translation>Artwork</translation>
    </message>
    <message>
        <source>About TepSonic</source>
        <translation>O TepSonicu</translation>
    </message>
    <message>
        <source>Supported formats</source>
        <translation>Podporované formáty</translation>
    </message>
    <message>
        <source>On this computer TepSonic can play following audio files:</source>
        <translation>Na tomto počítači dokáze TepSonic přehrát tyto audio soubory:</translation>
    </message>
    <message>
        <source>Playing: </source>
        <translation>Přehrávám:</translation>
    </message>
    <message>
        <source>%1 [paused]</source>
        <translation>%1 [pozastaveno]</translation>
    </message>
    <message>
        <source>Save playlist to...</source>
        <translation>Uložit playlist do...</translation>
    </message>
    <message>
        <source>M3U Playlist (*.m3u)</source>
        <translation>M3U Playlist (*.m3u)</translation>
    </message>
    <message>
        <source>Are you sure you want to remove all content of %1 from hard disk?</source>
        <translation>Opvradu chcete odstranit všechny soubory v %1 z disku?</translation>
    </message>
    <message>
        <source>Are you sure you want to remove track %1 (%2) from hard disk?</source>
        <translation>Opravdu chcete odstranit skladbu %1 (%2) z disku?</translation>
    </message>
    <message>
        <source>Confirm removal</source>
        <translation>Potvrďte odstranění</translation>
    </message>
</context>
<context>
    <name>PlayerPage</name>
    <message>
        <source>Form</source>
        <translation>Formulář</translation>
    </message>
    <message>
        <source>Restore previous session</source>
        <translation>Obnovit předchozí relaci</translation>
    </message>
</context>
<context>
    <name>PluginsPage</name>
    <message>
        <source>Form</source>
        <translation>Formulář</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Hlavní</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation>
            <numerusform>%n týden</numerusform>
            <numerusform>%n týdny</numerusform>
            <numerusform>%n týdnů</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation>
            <numerusform>%n den</numerusform>
            <numerusform>%n dny</numerusform>
            <numerusform>%n dní</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Přehrávač</translation>
    </message>
    <message>
        <source>Collections</source>
        <translation>Kolekce</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>Pluginy</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Zkratky</translation>
    </message>
    <message>
        <source>Play/pause</source>
        <translation>Play/Pauza</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Zastavit</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Předchozí skladba</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Následující skladba</translation>
    </message>
    <message>
        <source>Show/Hide window</source>
        <translation>Zobrazit/skrýt okno</translation>
    </message>
</context>
<context>
    <name>SettingsPages::CollectionsPage</name>
    <message>
        <source>Add directory</source>
        <translation>Přidat adresář</translation>
    </message>
</context>
<context>
    <name>ShortcutsPage</name>
    <message>
        <source>Form</source>
        <translation>Formulář</translation>
    </message>
    <message>
        <source>Function</source>
        <translation>Funkce</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Zkratka</translation>
    </message>
</context>
<context>
    <name>TaskManager</name>
    <message>
        <source>Rebuilding collections</source>
        <translation>Aktualizuji kolekce</translation>
    </message>
</context>
</TS>
